@@ -1,4 +1,7 @@
 package Math::Primality;
+{
+  $Math::Primality::VERSION = '0.05';
+}
 use warnings;
 use strict;
 use Data::Dumper;
@@ -69,71 +72,14 @@ use constant
 
 use constant GMP => 'Math::GMPz';
 
-=head1 NAME
+# ABSTRACT: Check for primes with Perl
 
-Math::Primality - Advanced Primality Algorithms using GMP
-
-=head1 VERSION
-
-Version 0.04
-
-=cut
-
-our $VERSION = '0.04';
-$VERSION = eval $VERSION;
 
 
 our @EXPORT_OK = qw/is_pseudoprime is_strong_pseudoprime is_strong_lucas_pseudoprime is_prime next_prime prev_prime prime_count/;
 
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
-=head1 SYNOPSIS
-
-    use Math::Primality qw/:all/;
-
-    my $t1 = is_pseudoprime($x,$base);
-    my $t2 = is_strong_pseudoprime($x);
-
-    print "Prime!" if is_prime($outrageously_large_prime);
-
-    my $t3 = next_prime($x); 
-
-=head1 DESCRIPTION
-
-Math::Primality implements is_prime() and next_prime() as a replacement for Math::PARI::is_prime().  It uses the GMP library through Math::GMPz.  The is_prime() method is actually a Baillie-PSW primality test which consists of two steps:
-
-=over 4
-
-=item * Perform a strong Miller-Rabin probable prime test (base 2) on N
-
-=item * Perform a strong Lucas-Selfridge test on N (using the parameters suggested by Selfridge)
-
-=back
-
-At any point the function may return 2 which means N is definitely composite.  If not, N has passed the strong Baillie-PSW test and is either prime or a strong Baillie-PSW pseudoprime.  To date no counterexample (Baillie-PSW strong pseudoprime) is known to exist for N < 10^15.  Baillie-PSW requires O((log n)^3) bit operations.  See L<http://www.trnicely.net/misc/bpsw.html> for a more thorough introduction to the Baillie-PSW test. Also see L<http://mpqs.free.fr/LucasPseudoprimes.pdf> for a more theoretical introduction to the Baillie-PSW test. 
-
-=head1 EXPORT
-
-=head1 FUNCTIONS
-
-=head2 is_pseudoprime($n,$b)
-
-Returns true if $n is a base $b pseudoprime, otherwise false.  The variable $n
-should be a Perl integer or Math::GMPz object.
-
-The default base of 2 is used if no base is given. Base 2 pseudoprimes are often called Fermat pseudoprimes.
-
-    if ( is_pseudoprime($n,$b) ) {
-        # it's a pseudoprime
-    } else {
-        # not a psuedoprime
-    }
-
-=head3 Details
-
-A pseudoprime is a number that satisfies Fermat's Little Theorm, that is, $b^ ($n - 1) = 1 mod $n.
-
-=cut
 
 sub is_pseudoprime($;$)
 {
@@ -168,36 +114,6 @@ sub debug {
     }
 }
 
-=head2 is_strong_pseudoprime($n,$b)
-
-Returns true if $n is a base $b strong pseudoprime, false otherwise.  The variable $n should be a Perl integer
-or a Math::GMPz object. Strong psuedoprimes are often called Miller-Rabin pseudoprimes.
-
-The default base of 2 is used if no base is given.
-
-    if ( is_strong_pseudoprime($n,$b) ) {
-        # it's a strong pseudoprime
-    } else {
-        # not a strong psuedoprime
-    }
-
-=head3 Details
-
-A strong pseudoprime to $base is an odd number $n with ($n - 1) = $d * 2^$s that either satisfies
-
-=over 4
-
-=item * $base^$d = 1 mod $n
-
-=item * $base^($d * 2^$r) = -1 mod $n, for $r = 0, 1, ..., $s-1
-
-=back
-
-=head3 Notes
-
-The second condition is checked by sucessive squaring $base^$d and reducing that mod $n.
-
-=cut
 
 sub is_strong_pseudoprime($;$)
 {
@@ -265,47 +181,6 @@ sub _find_s_d($)
     return ($s,$d);
 }
 
-=head2 is_strong_lucas_pseudoprime($n)
-
-Returns true if $n is a strong Lucas-Selfridge pseudoprime, false otherwise.  The variable $n should be a Perl
-integer or a Math::GMPz object.  
-
-    if ( is_strong_lucas_pseudoprime($n) ) {
-        # it's a strong Lucas-Selfridge pseudoprime
-    } else {
-        # not a strong Lucas-Selfridge psuedoprime
-        # i.e. definitely composite
-    }
-
-=head3 Details
-
-If we let
-
-=over 4
-
-=item * $D be the first element of the sequence 5, -7, 9, -11, 13, ... for which ($D/$n) = -1.  Let $P = 1 and $Q = (1 - $D) /4
-
-=item * U($P, $Q) and V($P, $Q) be Lucas sequences
-
-=item * $n + 1 = $d * 2^$s + 1
-
-=back
-
-Then a strong Lucas-Selfridge pseudoprime is an odd, non-perfect square number $n with that satisfies either
-
-=over 4
-
-=item * U_$d = 0 mod $n
-
-=item * V_($d * 2^$r) = 0 mod $n, for $r = 0, 1, ..., $s-1
-
-=back
-
-=head3 Notes
-
-($d/$n) refers to the Legendre symbol.
-
-=cut
 
 sub is_strong_lucas_pseudoprime($)
 {
@@ -462,6 +337,216 @@ sub _check_two_and_even($) {
   return 2;
 }
 
+
+sub is_prime($) {
+    my $n = shift;
+    $n = GMP->new($n);
+
+    if (Rmpz_cmp_ui($n, 2) == -1) {
+        return 0;
+    }
+    if (Rmpz_cmp_ui($n, 257) == -1) {
+        return _is_small_prime($n);
+    } elsif ( Rmpz_cmp_ui($n, 9_080_191) == -1 ) {
+        return 0 unless is_strong_pseudoprime($n,31);
+        return 0 unless is_strong_pseudoprime($n,73);
+        return 2;
+    } elsif ( Rmpz_cmp_ui($n, 4_759_123_141) == -1 ) {
+        return 0 unless is_strong_pseudoprime($n,2);
+        return 0 unless is_strong_pseudoprime($n,7);
+        return 0 unless is_strong_pseudoprime($n,61);
+        return 2;
+    }
+    # the strong_pseudoprime test is quicker, do it first
+    return is_strong_pseudoprime($n,2) && is_strong_lucas_pseudoprime($n);
+}
+
+
+sub next_prime($) {
+  my $n = GMP->new($_[0]);
+  my $cmp = Rmpz_cmp_ui($n, 2 ); #check if $n < 2
+  if ($cmp < 0) {
+    return GMP->new(2);
+  }
+  if (Rmpz_odd_p($n)) {         # if N is odd
+    Rmpz_add_ui($n, $n, 2);     # N = N + 2
+  } else {
+    Rmpz_add_ui($n, $n, 1);     # N = N + 1
+  }
+  # N is now the next odd number
+  while (1) {
+    return $n if is_prime($n);  # check primality of that number, return if prime
+    Rmpz_add_ui($n, $n, 2);     # N = N + 2
+  }
+}
+
+
+sub prev_prime($) {
+  my $n = GMP->new($_[0]);
+  my $cmp = Rmpz_cmp_ui($n, 3);   # compare N with 3
+  if ($cmp == 0) {                # N = 3
+    return GMP->new(2);
+  } elsif ($cmp < 0) {            # N < 3
+    return undef;
+  } else {
+    if (Rmpz_odd_p($n)) {         # if N is odd
+      Rmpz_sub_ui($n, $n, 2);     # N = N - 2
+    } else {
+      Rmpz_sub_ui($n, $n, 1);     # N = N - 1
+    }
+    # N is now the previous odd number
+    while (1) {
+      return $n if is_prime($n);  # check primality of that number, return if prime
+      Rmpz_sub_ui($n, $n, 2);     # N = N - 2
+    } 
+  }
+}
+
+
+sub prime_count($) {
+  my $n = GMP->new($_[0]); # check if $n needs to be a Math::GMPz object
+  my $primes = 0;
+  return 0 if $n <= 1;
+
+  for (my $i = GMP->new(0); Rmpz_cmp($i, $n) <= 0; Rmpz_add_ui($i, $i, 1)) {
+    $primes++ if is_prime($i);
+  }
+  return $primes;
+}
+
+
+exp(0); # End of Math::Primality
+
+__END__
+=pod
+
+=head1 NAME
+
+Math::Primality - Check for primes with Perl
+
+=head1 VERSION
+
+version 0.05
+
+=head1 SYNOPSIS
+
+    use Math::Primality qw/:all/;
+
+    my $t1 = is_pseudoprime($x,$base);
+    my $t2 = is_strong_pseudoprime($x);
+
+    print "Prime!" if is_prime($outrageously_large_prime);
+
+    my $t3 = next_prime($x); 
+
+=head1 DESCRIPTION
+
+Math::Primality implements is_prime() and next_prime() as a replacement for Math::PARI::is_prime().  It uses the GMP library through Math::GMPz.  The is_prime() method is actually a Baillie-PSW primality test which consists of two steps:
+
+=over 4
+
+=item * Perform a strong Miller-Rabin probable prime test (base 2) on N
+
+=item * Perform a strong Lucas-Selfridge test on N (using the parameters suggested by Selfridge)
+
+=back
+
+At any point the function may return 2 which means N is definitely composite.  If not, N has passed the strong Baillie-PSW test and is either prime or a strong Baillie-PSW pseudoprime.  To date no counterexample (Baillie-PSW strong pseudoprime) is known to exist for N < 10^15.  Baillie-PSW requires O((log n)^3) bit operations.  See L<http://www.trnicely.net/misc/bpsw.html> for a more thorough introduction to the Baillie-PSW test. Also see L<http://mpqs.free.fr/LucasPseudoprimes.pdf> for a more theoretical introduction to the Baillie-PSW test. 
+
+=head1 NAME
+
+Math::Primality - Advanced Primality Algorithms using GMP
+
+=head1 EXPORT
+
+=head1 FUNCTIONS
+
+=head2 is_pseudoprime($n,$b)
+
+Returns true if $n is a base $b pseudoprime, otherwise false.  The variable $n
+should be a Perl integer or Math::GMPz object.
+
+The default base of 2 is used if no base is given. Base 2 pseudoprimes are often called Fermat pseudoprimes.
+
+    if ( is_pseudoprime($n,$b) ) {
+        # it's a pseudoprime
+    } else {
+        # not a psuedoprime
+    }
+
+=head3 Details
+
+A pseudoprime is a number that satisfies Fermat's Little Theorm, that is, $b^ ($n - 1) = 1 mod $n.
+
+=head2 is_strong_pseudoprime($n,$b)
+
+Returns true if $n is a base $b strong pseudoprime, false otherwise.  The variable $n should be a Perl integer
+or a Math::GMPz object. Strong psuedoprimes are often called Miller-Rabin pseudoprimes.
+
+The default base of 2 is used if no base is given.
+
+    if ( is_strong_pseudoprime($n,$b) ) {
+        # it's a strong pseudoprime
+    } else {
+        # not a strong psuedoprime
+    }
+
+=head3 Details
+
+A strong pseudoprime to $base is an odd number $n with ($n - 1) = $d * 2^$s that either satisfies
+
+=over 4
+
+=item * $base^$d = 1 mod $n
+
+=item * $base^($d * 2^$r) = -1 mod $n, for $r = 0, 1, ..., $s-1
+
+=back
+
+=head3 Notes
+
+The second condition is checked by sucessive squaring $base^$d and reducing that mod $n.
+
+=head2 is_strong_lucas_pseudoprime($n)
+
+Returns true if $n is a strong Lucas-Selfridge pseudoprime, false otherwise.  The variable $n should be a Perl
+integer or a Math::GMPz object.  
+
+    if ( is_strong_lucas_pseudoprime($n) ) {
+        # it's a strong Lucas-Selfridge pseudoprime
+    } else {
+        # not a strong Lucas-Selfridge psuedoprime
+        # i.e. definitely composite
+    }
+
+=head3 Details
+
+If we let
+
+=over 4
+
+=item * $D be the first element of the sequence 5, -7, 9, -11, 13, ... for which ($D/$n) = -1.  Let $P = 1 and $Q = (1 - $D) /4
+
+=item * U($P, $Q) and V($P, $Q) be Lucas sequences
+
+=item * $n + 1 = $d * 2^$s + 1
+
+=back
+
+Then a strong Lucas-Selfridge pseudoprime is an odd, non-perfect square number $n with that satisfies either
+
+=over 4
+
+=item * U_$d = 0 mod $n
+
+=item * V_($d * 2^$r) = 0 mod $n, for $r = 0, 1, ..., $s-1
+
+=back
+
+=head3 Notes
+
+($d/$n) refers to the Legendre symbol.
+
 =head2 is_prime($n)
 
 Returns 2 if $n is definitely prime, 1 is $n is a probable prime, 0 if $n is composite.
@@ -489,31 +574,6 @@ We have implemented some optimizations.  We have an array of small primes to che
 L<http://primes.utm.edu/prove/prove2_3.html> if $n < 9,080,191 is a both a base-31 and a base-73 strong pseudoprime,
  then $n is prime. If $n < 4,759,123,141 is a base-2, base-7 and base-61 strong pseudoprime, then $n is prime.
 
-=cut
-
-sub is_prime($) {
-    my $n = shift;
-    $n = GMP->new($n);
-
-    if (Rmpz_cmp_ui($n, 2) == -1) {
-        return 0;
-    }
-    if (Rmpz_cmp_ui($n, 257) == -1) {
-        return _is_small_prime($n);
-    } elsif ( Rmpz_cmp_ui($n, 9_080_191) == -1 ) {
-        return 0 unless is_strong_pseudoprime($n,31);
-        return 0 unless is_strong_pseudoprime($n,73);
-        return 2;
-    } elsif ( Rmpz_cmp_ui($n, 4_759_123_141) == -1 ) {
-        return 0 unless is_strong_pseudoprime($n,2);
-        return 0 unless is_strong_pseudoprime($n,7);
-        return 0 unless is_strong_pseudoprime($n,61);
-        return 2;
-    }
-    # the strong_pseudoprime test is quicker, do it first
-    return is_strong_pseudoprime($n,2) && is_strong_lucas_pseudoprime($n);
-}
-
 =head2 next_prime($n)
 
 Given a number, produces the next prime number.
@@ -528,26 +588,6 @@ Each next greatest odd number is checked until one is found to be prime
 
 Checking of primality is implemented by is_prime()
 
-=cut
-
-sub next_prime($) {
-  my $n = GMP->new($_[0]);
-  my $cmp = Rmpz_cmp_ui($n, 2 ); #check if $n < 2
-  if ($cmp < 0) {
-    return GMP->new(2);
-  }
-  if (Rmpz_odd_p($n)) {         # if N is odd
-    Rmpz_add_ui($n, $n, 2);     # N = N + 2
-  } else {
-    Rmpz_add_ui($n, $n, 1);     # N = N + 1
-  }
-  # N is now the next odd number
-  while (1) {
-    return $n if is_prime($n);  # check primality of that number, return if prime
-    Rmpz_add_ui($n, $n, 2);     # N = N + 2
-  }
-}
-
 =head2 prev_prime($n)
 
 Given a number, produces the previous prime number.
@@ -562,29 +602,6 @@ Each previous odd number is checked until one is found to be prime.  prev_prime(
 
 Checking of primality is implemented by is_prime()
 
-=cut
-
-sub prev_prime($) {
-  my $n = GMP->new($_[0]);
-  my $cmp = Rmpz_cmp_ui($n, 3);   # compare N with 3
-  if ($cmp == 0) {                # N = 3
-    return GMP->new(2);
-  } elsif ($cmp < 0) {            # N < 3
-    return undef;
-  } else {
-    if (Rmpz_odd_p($n)) {         # if N is odd
-      Rmpz_sub_ui($n, $n, 2);     # N = N - 2
-    } else {
-      Rmpz_sub_ui($n, $n, 1);     # N = N - 1
-    }
-    # N is now the previous odd number
-    while (1) {
-      return $n if is_prime($n);  # check primality of that number, return if prime
-      Rmpz_sub_ui($n, $n, 2);     # N = N - 2
-    } 
-  }
-}
-
 =head2 prime_count($n)
 
 Returns the number of primes less than or equal to $n.
@@ -603,23 +620,9 @@ that describes this method in rigorous detail.
 
 Checking of primality is implemented by is_prime()
 
-=cut
-
-sub prime_count($) {
-  my $n = GMP->new($_[0]); # check if $n needs to be a Math::GMPz object
-  my $primes = 0;
-  return 0 if $n <= 1;
-
-  for (my $i = GMP->new(0); Rmpz_cmp($i, $n) <= 0; Rmpz_add_ui($i, $i, 1)) {
-    $primes++ if is_prime($i);
-  }
-  return $primes;
-}
-
-
 =head1 AUTHORS
 
-Jonathan Leto, C<< <jonathan at leto.net> >>
+Jonathan "Duke" Leto, C<< <jonathan at leto.net> >>
 Bob Kuo, C<< <bobjkuo at gmail.com> >>
 
 =head1 BUGS
@@ -630,7 +633,6 @@ L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Math::Primality>.  I will be
 notified, and then you'll automatically be notified of progress on your bug as I
 make changes.
 
-
 =head1 THANKS
 
 The algorithms in this module have been ported from the C source code in
@@ -647,7 +649,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Math::Primality
 
-
 You can also look for information at:
 
 =over 4
@@ -674,18 +675,25 @@ L<http://search.cpan.org/dist/Math::Primality>
 
 =back
 
-
 =head1 ACKNOWLEDGEMENTS
 
-
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009 Jonathan Leto, all rights reserved.
+Copyright 2009-2011 Jonathan "Duke" Leto, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Jonathan "Duke" Leto <jonathan@leto.net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Leto Labs LLC.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-exp(0); # End of Math::Primality
